@@ -9,7 +9,7 @@
 #
 package Config::Model::Tk::ListEditor ;
 {
-  $Config::Model::Tk::ListEditor::VERSION = '1.330';
+  $Config::Model::Tk::ListEditor::VERSION = '1.332';
 }
 
 use strict;
@@ -120,7 +120,7 @@ sub Populate {
         -command => sub {
             $list->clear;
             $tklist->delete( 0, 'end' );
-            $cw->reload_tree;
+            $cw->{store_cb}->() ;
         },
     )->pack( -side => 'left', @fxe1 );
     $balloon->attach( $rm_all_b, -msg => 'Remove all elements from the list' );
